# Design Documents for Proposed Features

Proposed features in this directory have reached some level of consensus within the 
community, indicating that they have potential and deserve further development. 
However, the proposed changes have not yet been released as a
preview or fully supported feature of the library.

RFCs in the `rfcs/proposed` directory should explain the motivation,
design, and open questions related to the proposed extension.
